@@ -1,5 +1,5 @@
 /* client-xmpp-saml20.c --- Example XMPP SASL SAML20 client.
- * Copyright (C) 2004, 2005, 2007, 2009, 2010, 2012  Simon Josefsson
+ * Copyright (C) 2004-2012 Simon Josefsson
  *
  * This file is part of GNU SASL.
  *
@@ -66,7 +66,13 @@ client_xmpp (Gsasl_session * session)
     {
       char *b64;
 
-      fgets (buf, sizeof (buf) - 1, stdin);
+      p = fgets (buf, sizeof (buf) - 1, stdin);
+      if (p == NULL)
+	{
+	  perror ("fgets");
+	  return;
+	}
+
       if (buf[strlen (buf) - 1] == '\n')
         buf[strlen (buf) - 1] = '\0';
 
@@ -84,6 +90,7 @@ client_xmpp (Gsasl_session * session)
       printf ("<response xmlns='urn:ietf:params:xml:ns:xmpp-sasl'>"
 	      "%s</response>\n", p);
 
+      gsasl_free (p);
     }
   while (rc == GSASL_NEEDS_MORE);
 
@@ -134,9 +141,9 @@ callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
       rc = GSASL_OK;
       break;
 
-    case GSASL_SAML20_AUTHENTICATE_IN_BROWSER:
+    case GSASL_AUTHENTICATE_IN_BROWSER:
       printf ("client got redirect URL: %s\n",
-	      gsasl_property_get (sctx, GSASL_SAML20_REDIRECT_URL));
+	      gsasl_property_get (sctx, GSASL_REDIRECT_URL));
       rc = GSASL_OK;
       break;
 
