@@ -43,14 +43,19 @@ client_authenticate (Gsasl_session * session)
         {
           /* If sucessful, print it. */
           printf ("Output:\n%s\n", p);
-          free (p);
+          gsasl_free (p);
         }
 
       if (rc == GSASL_NEEDS_MORE)
         {
           /* If the client need more data from server, get it here. */
           printf ("Input base64 encoded data from server:\n");
-          fgets (buf, sizeof (buf) - 1, stdin);
+          p = fgets (buf, sizeof (buf) - 1, stdin);
+	  if (p == NULL)
+	    {
+	      perror ("fgets");
+	      return;
+	    }
           if (buf[strlen (buf) - 1] == '\n')
             buf[strlen (buf) - 1] = '\0';
         }
