@@ -21,20 +21,20 @@
  */
 
 #ifndef INTERNAL_H
-# define INTERNAL_H
+#define INTERNAL_H
 
-# ifdef HAVE_CONFIG_H
-#  include "config.h"
-# endif
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 /* Get specifications. */
-# include "gsasl.h"
+#include "gsasl.h"
 
 /* Get malloc, free, ... */
-# include <stdlib.h>
+#include <stdlib.h>
 
 /* Get strlen, strcpy, ... */
-# include <string.h>
+#include <string.h>
 
 /* Main library handle. */
 struct Gsasl
@@ -103,8 +103,8 @@ struct Gsasl_session
   char *scram_salted_password;
   char *cb_tls_unique;
   char *saml20_idp_identifier;
-  char *saml20_redirect_url;
-  char *openid20_auth_identifier;
+  char *redirect_url;
+  char *openid20_outcome_data;
   /* If you add anything here, remember to change change
      gsasl_finish() in xfinish.c and map() in property.c.  */
 
@@ -115,8 +115,8 @@ struct Gsasl_session
 };
 
 #ifndef GSASL_NO_OBSOLETE
-const char *
-_gsasl_obsolete_property_map (Gsasl_session * sctx, Gsasl_property prop);
+const char *_gsasl_obsolete_property_map (Gsasl_session * sctx,
+					  Gsasl_property prop);
 int _gsasl_obsolete_callback (Gsasl * ctx, Gsasl_session * sctx,
 			      Gsasl_property prop);
 #endif
